import React, { useEffect, useState } from 'react';
import { Header, PageWrapper } from '../../../../components';
import { getOnlineStatus, storage, StoreType } from '../../../../storage';

import { Profile } from '../Components/Profile';

import { Ranking } from '../Ranking';
import { FlatList } from 'react-native';
import { fetchFullRanking } from '@api/ranking';

const MasterRankingScreen = () => {
  const [masterRanking, setMasterRanking] = useState<Ranking[]>([]);
  const { mutateAsync } = fetchFullRanking();

  const ranking = storage.get('masterRanking', StoreType.STRING) as string;

  useEffect(() => {
    setMasterRanking(JSON.parse(ranking).sort((a: Ranking, b: Ranking) => b.score_nm - a.score_nm));
  }, []);

  const getFullRanking = async () => {
    if (getOnlineStatus()) {
      await mutateAsync(undefined, {
        onSuccess: (data) => {
          setMasterRanking(data.data);
        }
      });
    }
  };

  return (
    <PageWrapper>
      <Header label="Master Ranking" />
      <FlatList
        data={masterRanking}
        keyExtractor={(item) => item.user_id.toString()}
        renderItem={({ item, index }) => (
          <Profile
            index={index}
            first_name={item.first_name}
            last_name={item.last_name}
            avatar={item.avatar}
            date_of_birth={item.age}
            homebase_flag={item.flag1}
            homebase2_flag={item.flag2}
            score={[
              item.score_nm,
              item.score_dare,
              item.score_un,
              item.score_unp,
              item.score_tcc,
              item.score_yes,
              item.score_slow,
              item.score_whs,
              item.score_kye
            ]}
            tbt_score={item.score_tbt}
          />
        )}
        onEndReached={() => getFullRanking()}
        onEndReachedThreshold={0.8}
      />
    </PageWrapper>
  );
};

export default MasterRankingScreen;
